# Connect4 python module

[![wakatime](https://wakatime.com/badge/github/AiroPi/connect4-python-module.svg)](https://wakatime.com/badge/github/AiroPi/connect4-python-module)
[![timed project](https://img.shields.io/badge/dynamic/json?color=blueviolet&label=%23&prefix=timedproject%20%3A%20&query=total_count&url=https%3A%2F%2Fapi.github.com%2Fsearch%2Frepositories%3Fq%3D%2523timedproject%2Buser%3AAiroPi)](https://github.com/AiroPi?tab=repositories&q=%23timedproject)
[![weekly project](https://img.shields.io/badge/dynamic/json?color=blueviolet&label=%23&prefix=weeklyproject%20%3A%20&query=total_count&url=https%3A%2F%2Fapi.github.com%2Fsearch%2Frepositories%3Fq%3D%2523weeklyproject%2Buser%3AAiroPi)](https://github.com/AiroPi?tab=repositories&q=%23weeklyproject)

**Objective:** under 1 week  
**Realization:** 2 days

---
A simple module to manage a connect4 game.

TODO : add examples and documentation

---
<details>
  <summary><b>About timed projects</b></summary>
  
  A [timed project](https://github.com/AiroPi?tab=repositories&q=%23timedproject&type=&language=&sort=) is a project idea that I have to realize under a time I defined. It is a challenge for me to respect the time.  
</details>
<details>
  <summary><b>Others examples</b></summary>

[![timed project](https://img.shields.io/badge/dynamic/json?color=blueviolet&label=%23&prefix=timedproject%20%3A%20&query=total_count&url=https%3A%2F%2Fapi.github.com%2Fsearch%2Frepositories%3Fq%3D%2523timedproject%2Buser%3AAiroPi)](https://github.com/AiroPi?tab=repositories&q=%23timedproject)
[![hourly project](https://img.shields.io/badge/dynamic/json?color=blueviolet&label=%23&prefix=hourlyproject%20%3A%20&query=total_count&url=https%3A%2F%2Fapi.github.com%2Fsearch%2Frepositories%3Fq%3D%2523hourlyproject%2Buser%3AAiroPi)](https://github.com/AiroPi?tab=repositories&q=%23hourlyproject)
[![daily project](https://img.shields.io/badge/dynamic/json?color=blueviolet&label=%23&prefix=dailyproject%20%3A%20&query=total_count&url=https%3A%2F%2Fapi.github.com%2Fsearch%2Frepositories%3Fq%3D%2523dailyproject%2Buser%3AAiroPi)](https://github.com/AiroPi?tab=repositories&q=%23dailyproject)
[![weekly project](https://img.shields.io/badge/dynamic/json?color=blueviolet&label=%23&prefix=weeklyproject%20%3A%20&query=total_count&url=https%3A%2F%2Fapi.github.com%2Fsearch%2Frepositories%3Fq%3D%2523weeklyproject%2Buser%3AAiroPi)](https://github.com/AiroPi?tab=repositories&q=%23weeklyproject)
[![monthly project](https://img.shields.io/badge/dynamic/json?color=blueviolet&label=%23&prefix=monthlyproject%20%3A%20&query=total_count&url=https%3A%2F%2Fapi.github.com%2Fsearch%2Frepositories%3Fq%3D%2523monthlyproject%2Buser%3AAiroPi)](https://github.com/AiroPi?tab=repositories&q=%23monthlyproject)
</details>
